==> node-sdk-0.1.14.tgz: package/esm/internal/wasm.js <==
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { WASMRequest, WASMResponse } from "@streamdal/protos/protos/sp_wsm";
// eslint-disable-next-line import/no-unresolved
import { WASI } from "wasi";
import { internal } from "./register.js";
const [nodeVersionMajor] = process.versions.node.split(".");
const wasi = new WASI(Object.assign(Object.assign({}, (Number(nodeVersionMajor) >= 20 ? { version: "preview1" } : {})), { preopens: {
        "/sandbox": "./",
    } }));
export const instantiateWasm = (wasmId, wasmBytes, wasmFunction) => __awaiter(void 0, void 0, void 0, function* () {
    if (!wasmId || !wasmBytes || !wasmFunction) {
        console.debug("Wasm info missing, skipping instantiation, .");
        return;
    }
    if (internal.wasmModules.has(wasmId)) {
        console.debug("Wasm exists, skipping instantiation");
        return;
    }
    const wasm = yield WebAssembly.compile(wasmBytes);
    const importObject = { wasi_snapshot_preview1: wasi.wasiImport };
    const instance = yield WebAssembly.instantiate(wasm, importObject);
    const { exports } = instance;
    const { memory, alloc, [wasmFunction]: f } = exports;
    internal.wasmModules.set(wasmId, { memory, alloc, f });
});
export const readResponse = (pointer, buffer) => {
    let nullHits = 0;
    const data = [];
    for (let i = pointer; i < buffer.length; i++) {
        //
        // Have three nulls in a row, can quit
        if (nullHits === 3) {
            break;
        }
        // Don't have a length, have to see if we hit three sequential terminators
        if (buffer[i] === 166) {
            nullHits++;
            continue;
        }
        // Not a terminator, reset null hits
        nullHits = 0;
        data.push(buffer[i]);
    }
    return new Uint8Array(data);
};
export const runWasm = ({ step, data, }) => {
    const request = WASMRequest.create({
        step: {
            name: step.name,
            onSuccess: step.onSuccess,
            onFailure: step.onFailure,
            step: step.step,
        },
        inputPayload: data,
    });
    const requestBytes = WASMRequest.toBinary(request);
    const { memory, alloc, f } = internal.wasmModules.get(step.WasmId);
    const ptr = alloc(requestBytes.length);
    const mem = new Uint8Array(memory.buffer, ptr, requestBytes.length);
    mem.set(requestBytes);
    const returnPtr = f(ptr, requestBytes.length);
    const completeBufferFromMemory = new Uint8Array(memory.buffer);
    const response = readResponse(returnPtr, completeBufferFromMemory);
    const decodedResponse = WASMResponse.fromBinary(response);
    return decodedResponse;
};

==> node-sdk-0.1.15.tgz: package/esm/internal/wasm.js <==
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { WASMRequest, WASMResponse } from "@streamdal/protos/protos/sp_wsm";
// eslint-disable-next-line import/no-unresolved
import { WASI } from "wasi";
import { internal } from "./register.js";
const [nodeVersionMajor] = process.versions.node.split(".");
const wasi = new WASI(Object.assign(Object.assign({}, (Number(nodeVersionMajor) >= 20 ? { version: "preview1" } : {})), { preopens: {
        "/sandbox": "./",
    } }));
export const instantiateWasm = (wasmId, wasmBytes, wasmFunction) => __awaiter(void 0, void 0, void 0, function* () {
    if (!wasmId || !wasmFunction || !wasmBytes || wasmBytes.length === 0) {
        console.debug("Wasm info missing, skipping instantiation, .");
        return;
    }
    if (internal.wasmModules.has(wasmId)) {
        console.debug("Wasm exists, skipping instantiation");
        return;
    }
    const wasm = yield WebAssembly.compile(wasmBytes);
    const importObject = { wasi_snapshot_preview1: wasi.wasiImport };
    const instance = yield WebAssembly.instantiate(wasm, importObject);
    const { exports } = instance;
    const { memory, alloc, [wasmFunction]: f } = exports;
    internal.wasmModules.set(wasmId, { memory, alloc, f });
});
export const readResponse = (pointer, buffer) => {
    let nullHits = 0;
    const data = [];
    for (let i = pointer; i < buffer.length; i++) {
        //
        // Have three nulls in a row, can quit
        if (nullHits === 3) {
            break;
        }
        // Don't have a length, have to see if we hit three sequential terminators
        if (buffer[i] === 166) {
            nullHits++;
            continue;
        }
        // Not a terminator, reset null hits
        nullHits = 0;
        data.push(buffer[i]);
    }
    return new Uint8Array(data);
};
export const runWasm = ({ step, data, }) => {
    const request = WASMRequest.create({
        step: {
            name: step.name,
            onSuccess: step.onSuccess,
            onFailure: step.onFailure,
            step: step.step,
        },
        inputPayload: data,
    });
    const requestBytes = WASMRequest.toBinary(request);
    const { memory, alloc, f } = internal.wasmModules.get(step.WasmId);
    const ptr = alloc(requestBytes.length);
    const mem = new Uint8Array(memory.buffer, ptr, requestBytes.length);
    mem.set(requestBytes);
    const returnPtr = f(ptr, requestBytes.length);
    const completeBufferFromMemory = new Uint8Array(memory.buffer);
    const response = readResponse(returnPtr, completeBufferFromMemory);
    const decodedResponse = WASMResponse.fromBinary(response);
    return decodedResponse;
};
